const { createApp, ref, computed } = Vue

const MIN_AMOUNT = +LC_CONFIG.MIN_AMOUNT
const MAX_AMOUNT = +LC_CONFIG.MAX_AMOUNT
const INTEREST_RATE = +LC_CONFIG.INTEREST_RATE / 100
const PRESET_AMOUNTS = [MIN_AMOUNT, ...LC_CONFIG.PRESET_AMOUNTS.map(el => +el), MAX_AMOUNT]
const CURRENCY_SYMBOL = LC_CONFIG.currency_symbol || '₽'

const TERM_LINK = LC_CONFIG.terms_link
const PRODUCTS_LINK = LC_CONFIG.products_link

const MAX_TERM = +LC_CONFIG.max_term

const PHONE_MASK = LC_CONFIG.phone_mask || '+7 (###) ###-##-##'
const PHONE_CODE = PHONE_MASK.split('(')[0].trim()

createApp({
  setup() {
    const amount = ref(MIN_AMOUNT)
    const term = ref(3)
    const monthlyPayment = ref(1400)
    const fullName = ref('')
    const phone = ref('')
    const showRequired = ref(false)
    const isLoading = ref(false)
    const isSubmitted = ref(false)


    const sliderValue = computed({
      get: () => {
        if (amount.value <= PRESET_AMOUNTS[1]) {
          return (amount.value - MIN_AMOUNT) / (PRESET_AMOUNTS[1] - MIN_AMOUNT) * 33.33
        } else if (amount.value <= PRESET_AMOUNTS[2]) {
          return 33.33 + (amount.value - PRESET_AMOUNTS[1]) / (PRESET_AMOUNTS[2] - PRESET_AMOUNTS[1]) * 33.33
        } else {
          return 66.66 + (amount.value - PRESET_AMOUNTS[2]) / (MAX_AMOUNT - PRESET_AMOUNTS[2]) * 33.34
        }
      },
      set: (value) => {
        let roundTo = 10000 // базовое округление до 10000

        if (value <= 33.33) {
          // Для значений меньше или равных MIN_AMOUNT используем округление до 100
          const calculatedAmount = value / 33.33 * (PRESET_AMOUNTS[1] - MIN_AMOUNT) + MIN_AMOUNT
          roundTo = calculatedAmount <= 10000 ? 100 : 10000
          amount.value = Math.round(calculatedAmount / roundTo) * roundTo
        } else if (value <= 66.66) {
          amount.value = Math.round(((value - 33.33) / 33.33 * (PRESET_AMOUNTS[2] - PRESET_AMOUNTS[1]) + PRESET_AMOUNTS[1]) / roundTo) * roundTo
        } else {
          // Для значений больше 1 000 000 используем шаг 500 000
          const calculatedAmount = ((value - 66.66) / 33.34 * (MAX_AMOUNT - PRESET_AMOUNTS[2]) + PRESET_AMOUNTS[2])
          roundTo = calculatedAmount > 1000000 ? 500000 : 10000
          amount.value = Math.round(calculatedAmount / roundTo) * roundTo
        }
      }
    })

    const calculateMonthlyPayment = () => {
      const principal = amount.value
      const years = term.value
      const monthlyInterestRate = INTEREST_RATE / 12
      const numberOfPayments = years * 12
      const payment = (principal * monthlyInterestRate) / (1 - Math.pow(1 + monthlyInterestRate, -numberOfPayments))
      monthlyPayment.value = Math.round(payment)
    }

    const formatNumber = (value) => {
      return new Intl.NumberFormat('ru-RU').format(value)
    }

    const formattedAmount = computed(() => formatNumber(amount.value))

    const formattedTerm = computed(() => term.value.toString())

    const handleAmountInput = (event) => {
      const numericValue = parseInt(event.target.value.replace(/\D/g, ''))
      amount.value = isNaN(numericValue) ? MIN_AMOUNT : Math.min(Math.max(numericValue, MIN_AMOUNT), MAX_AMOUNT)
      calculateMonthlyPayment()
    }

    const handleAmountBlur = (event) => {
      const numericValue = parseInt(event.target.value.replace(/\D/g, ''))
      const value = isNaN(numericValue) ? MIN_AMOUNT : Math.min(Math.max(numericValue, MIN_AMOUNT), MAX_AMOUNT)
      amount.value = value
      event.target.value = formattedAmount.value + ' ' + CURRENCY_SYMBOL
      calculateMonthlyPayment()
    }
    const handleAmountFocus = (event) => {
      const input = event.target
      input.value = amount.value
    }

    const handleTermInput = (event) => {
      const numericValue = parseInt(event.target.value.replace(/\D/g, ''))
      term.value = isNaN(numericValue) ? 1 : Math.min(Math.max(numericValue, 1), 15)
    }

    const handleTermBlur = (event) => {
      const numericValue = parseInt(event.target.value.replace(/\D/g, ''))
      term.value = 0
      const value = isNaN(numericValue) ? 1 : Math.min(Math.max(numericValue, 1), MAX_TERM)
      term.value = value

      calculateMonthlyPayment()
    }
    const handleTermFocus = () => {
      const input = event.target
      input.value = term.value
    }

    const getYearDeclension = (years) => {
      const lastDigit = years % 10
      const lastTwoDigits = years % 100

      if (lastDigit === 1 && lastTwoDigits !== 11) {
        return LC_TRANSLATIONS.year
      } else if ([2, 3, 4].includes(lastDigit) && ![12, 13, 14].includes(lastTwoDigits)) {
        return LC_TRANSLATIONS.years2_4
      } else {
        return LC_TRANSLATIONS.years5_more
      }
    }

    const setAmount = (value) => {
      amount.value = value
      calculateMonthlyPayment()
    }

    const capitalizeWords = () => {
      if (fullName.value) {
        fullName.value = fullName.value.split(' ').map(word =>
          word.charAt(0).toUpperCase() + word.slice(1).toLowerCase()
        ).join(' ')
      }
    }

    const initializePhone = () => {

    }

    const formatPhone = (event) => {
      const input = event.target
      let cleaned = phone.value.replace(/\D/g, '')
      const countryCode = PHONE_CODE.replace(/[\s+]/g, '')

      if (cleaned.startsWith('8') && countryCode === '7') {
        cleaned = '7' + cleaned.slice(1)
      }

      if (!cleaned.startsWith(countryCode)) {
        cleaned = countryCode + cleaned
      }

      const maxDigits = (PHONE_MASK.match(/#/g) || []).length + countryCode.length
      if (cleaned.length > maxDigits) {
        cleaned = cleaned.slice(0, maxDigits)
      }

      let result = PHONE_MASK.replace(PHONE_CODE, '').trim()
      let digitIndex = countryCode.length

      for (let i = 0; i < result.length && digitIndex < cleaned.length; i++) {
        if (result[i] === '#') {
          result = result.substring(0, i) + cleaned[digitIndex] + result.substring(i + 1)
          digitIndex++
        }
      }

      const lastDigitPos = result.lastIndexOf(cleaned[digitIndex - 1])
      phone.value = result.substring(0, lastDigitPos + 1)


    }

    const handlePhoneClick = (event) => {
      const input = event.target

    }

    const isValidFullName = computed(() => {
      const words = fullName.value.trim().split(/\s+/)
      const requiredWords = +LC_CONFIG.required_name_words || 3
      return words.length === requiredWords
    })

    const fullPhone = computed(() => PHONE_CODE + ' ' + phone.value)

    const isValidPhone = computed(() => {
      const escapedMask = PHONE_MASK
        .replace(/[+()]/g, '\\$&')
        .replace(/[-\s]/g, '\\$&')
        .replace(/#/g, '\\d')

      console.log('file: app.js:204 ~ fullPhone:', fullPhone)

      const phonePattern = new RegExp('^' + escapedMask + '$')
      return phonePattern.test(fullPhone.value)
    })

    const submitForm = async () => {
      showRequired.value = true

      if (isValidFullName.value && isValidPhone.value) {
        isLoading.value = true

        try {
          const formData = new FormData()
          formData.append('action', 'submit_loan_application')
          formData.append('nonce', LC_CONFIG.nonce)
          formData.append('phone', fullPhone.value)
          formData.append('full_name', fullName.value)
          formData.append('amount', amount.value)
          formData.append('term', term.value)
          formData.append('monthly_payment', monthlyPayment.value)

          const response = await fetch(LC_CONFIG.ajax_url, {
            method: 'POST',
            body: formData
          })

          const result = await response.json()

          if (result.success) {
            isSubmitted.value = true
          } else {
            alert(result.data || LC_TRANSLATIONS.form_error)
          }
        } catch (error) {
          console.error('Error:', error)
          alert(LC_TRANSLATIONS.form_error)
        } finally {
          isLoading.value = false
        }
      } else {
        alert(LC_TRANSLATIONS.validation_error)
      }
    }

    calculateMonthlyPayment()

    return {
      MIN_AMOUNT,
      MAX_AMOUNT,
      MAX_TERM,
      PRESET_AMOUNTS,
      amount,
      term,
      monthlyPayment,
      fullName,
      phone,
      showRequired,
      isLoading,
      isSubmitted,
      sliderValue,
      formattedAmount,
      formattedTerm,
      handleAmountInput,
      handleAmountBlur,
      handleTermInput,
      handleTermBlur,
      getYearDeclension,
      setAmount,
      capitalizeWords,
      initializePhone,
      formatPhone,
      isValidFullName,
      isValidPhone,
      submitForm,
      formatNumber,
      calculateMonthlyPayment,
      handleAmountFocus,
      handleTermFocus,
      handlePhoneClick,
    }
  }
}).mount('#app')
