<?php
/*
Plugin Name: Loan Calculator
Description: Loan calculator with settings and Vue.js
Version: 2.0.0
Requires PHP: 7.2
Author: Mikhail Kostikov
License: GPL v2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: loan-calculator
Domain Path: /languages
*/

define('LC_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('LC_PLUGIN_URL', plugin_dir_url(__FILE__));

class LoanCalculator
{
  private $options;

  public function __construct()
  {
    // Добавляем отладку
    add_action('init', function () {
      error_log('Current locale: ' . get_locale());
      error_log('Current language: ' . determine_locale());
    });

    // Меняем приоритет загрузки переводов на более ранний
    add_action('plugins_loaded', [$this, 'load_plugin_textdomain'], 5);

    require_once plugin_dir_path(__FILE__) . 'includes/loan-application-meta.php';

    add_action('init', [$this, 'register_shortcodes']);
    add_action('admin_menu', [$this, 'add_admin_menu']);
    add_action('admin_init', [$this, 'register_settings']);
    add_action('wp_ajax_calculate_loan', [$this, 'ajax_calculate_loan']);
    add_action('wp_ajax_nopriv_calculate_loan', [$this, 'ajax_calculate_loan']);
    add_action('wp_enqueue_scripts', [$this, 'enqueue_scripts']);
    add_action('wp_ajax_submit_loan_application', [$this, 'ajax_submit_loan_application']);
    add_action('wp_ajax_nopriv_submit_loan_application', [$this, 'ajax_submit_loan_application']);
    add_action('init', [$this, 'register_post_type']);
    add_action('init', 'register_loan_application_meta');
    add_action('save_post_loan_application', [$this, 'save_loan_application'], 10, 2);
    add_filter('manage_loan_application_posts_columns', [$this, 'set_custom_columns']);
    add_action('manage_loan_application_posts_custom_column', [$this, 'custom_column_content'], 10, 2);
    add_filter('manage_edit-loan_application_sortable_columns', [$this, 'set_sortable_columns']);
    add_filter('plugin_action_links_' . plugin_basename(__FILE__), [$this, 'add_settings_link']);
  }

  public function load_plugin_textdomain()
  {
    $domain = 'loan-calculator';
    $locale = apply_filters('plugin_locale', determine_locale(), $domain);


    // Загружаем перевод из папки languages в wp-content/languages/plugins если он там есть
    load_textdomain(
      $domain,
      WP_LANG_DIR . '/plugins/' . $domain . '-' . $locale . '.mo'
    );

    // Загружаем перевод из папки плагина
    load_plugin_textdomain(
      $domain,
      false,
      dirname(plugin_basename(__FILE__)) . '/languages'
    );
  }

  public function register_shortcodes()
  {
    add_shortcode('loan_calculator', [$this, 'render_calculator']);
  }

  public function render_calculator($atts)
  {
    $defaults = get_option('loan_calculator_settings', [
      'MIN_AMOUNT' => 10000,
      'MAX_AMOUNT' => 5000000,
      'INTEREST_RATE' => 0.1,
      'max_term' => 15,
      'PRESET_AMOUNTS' => "50000, 100000, 500000, 1000000",
      'currency_symbol' => '₽',
      'phone_mask' => '+7 (###) ###-##-##',
      'required_name_words' => 3
    ]);

    $defaults['PRESET_AMOUNTS'] = explode(',', $defaults['PRESET_AMOUNTS']);

    wp_enqueue_script('vue', 'https://unpkg.com/vue@3/dist/vue.global.js', [], null, true);
    wp_enqueue_script('loan-calculator-app', plugin_dir_url(__FILE__) . 'app.js', ['vue'], null, true);
    wp_enqueue_style('loan-calculator-style', plugin_dir_url(__FILE__) . 'style.css');

    ob_start();
    include plugin_dir_path(__FILE__) . 'includes/calculator-template.php';

    wp_localize_script('loan-calculator-app', 'LC_CONFIG', array_merge($defaults, [
      'ajax_url' => admin_url('admin-ajax.php'),
      'nonce' => wp_create_nonce('loan_calculator_nonce')
    ]));

    wp_localize_script('loan-calculator-app', 'LC_TRANSLATIONS', array(
      'year' => __('year', 'loan-calculator'),
      'years2_4' => __('years', 'loan-calculator'), // для 2-4 лет
      'years5_more' => __('years', 'loan-calculator'), // для 5+ лет
      'form_error' => __('An error occurred while submitting the form', 'loan-calculator'),
      'validation_error' => __('Please fill in all required fields correctly', 'loan-calculator'),
      'success_message' => __('Form submitted successfully', 'loan-calculator'),
    ));

    return ob_get_clean();
  }

  public function ajax_calculate_loan()
  {
    $amount = floatval($_POST['amount']);
    $rate = floatval($_POST['rate']) / 100 / 12; // месячная ставка
    $months = intval($_POST['months']);

    // Расчет аннуитетного платежа
    $monthly_payment = $amount * ($rate * pow(1 + $rate, $months)) / (pow(1 + $rate, $months) - 1);
    $total_payment = $monthly_payment * $months;
    $overpayment = $total_payment - $amount;

    wp_send_json_success([
      'monthly_payment' => round($monthly_payment, 2),
      'total_payment' => round($total_payment, 2),
      'overpayment' => round($overpayment, 2)
    ]);
  }

  public function add_admin_menu()
  {
    add_options_page(
      'Loan Calculator Settings',
      'Loan Calculator',
      'manage_options',
      'loan-calculator',
      [$this, 'render_admin_page']
    );
  }

  public function register_settings()
  {
    register_setting('loan_calculator_options', 'loan_calculator_settings');
  }

  public function render_admin_page()
  {
    include plugin_dir_path(__FILE__) . 'includes/admin-template.php';
  }

  public function enqueue_scripts() {}

  public function ajax_submit_loan_application()
  {
    // Проверка nonce для безопасности
    if (!wp_verify_nonce($_POST['nonce'], 'loan_calculator_nonce')) {
      wp_send_json_error('Ошибка безопасности');
    }

    // Валидация данных
    $phone = sanitize_text_field($_POST['phone']);
    $full_name = sanitize_text_field($_POST['full_name']);
    $amount = floatval($_POST['amount']);
    $term = intval($_POST['term']);
    $monthly_payment = floatval($_POST['monthly_payment']);

    // Проверка обязательных полей
    if (empty($phone) || empty($full_name) || empty($amount) || empty($term)) {
      wp_send_json_error('Все поля обязательны для заполнения');
    }

    // Проверка формата телефона - убираем жесткую проверку на конкретный формат
    if (empty($phone)) {
      wp_send_json_error('Телефон обязателен для заполнения');
    }



    // Создание записи заявки
    $application_data = [
      'post_title'  => 'Заявка',
      'post_type'   => 'loan_application',
      'post_status' => 'publish',
    ];

    $post_id = wp_insert_post($application_data);

    if ($post_id) {
      // Сохранение дополнительных полей
      update_post_meta($post_id, '_phone', $phone);
      update_post_meta($post_id, '_full_name', $full_name);
      update_post_meta($post_id, '_amount', $amount);
      update_post_meta($post_id, '_term', $term);
      update_post_meta($post_id, '_monthly_payment', $monthly_payment);
      update_post_meta($post_id, '_status', 'new');
      update_post_meta($post_id, '_date', current_time('mysql'));

      // Отправка уведомления администратору
      $admin_email = get_option('admin_email');
      $subject = 'Новая заявка на кредит';
      $message = "Получена новая заявка на кредит:\n\n";
      $message .= "ФИО: $full_name\n";
      $message .= "Телефон: $phone\n";
      $message .= "Сумма: $amount\n";
      $message .= "Срок: $term месяцев\n";
      $message .= "Ежемесячный платеж: $monthly_payment\n";

      wp_mail($admin_email, $subject, $message);

      wp_send_json_success([
        'message' => 'Заявка успешно отправлена',
        'application_id' => $post_id
      ]);
    } else {
      wp_send_json_error('Ошибка при сохранении заявки');
    }
  }

  public function register_post_type()
  {
    register_post_type('loan_application', [
      'labels' => [
        'name' => __('Loan Applications', 'loan-calculator'),
        'singular_name' => __('Loan Application', 'loan-calculator'),
        'edit_item' => __('View Application', 'loan-calculator'),
        'view_item' => __('View Application', 'loan-calculator'),
        'search_items' => __('Search Applications', 'loan-calculator'),
        'not_found' => __('No applications found', 'loan-calculator'),
        'not_found_in_trash' => __('No applications found in trash', 'loan-calculator')
      ],
      'public' => false,
      'show_ui' => true,
      'show_in_menu' => true,
      'menu_icon' => 'dashicons-money-alt',
      'capability_type' => 'post',
      'capabilities' => [
        'create_posts' => false
      ],
      'map_meta_cap' => true,
      'hierarchical' => false,
      'supports' => ['title'],
      'register_meta_box_cb' => [$this, 'add_meta_boxes']
    ]);
  }

  public function add_meta_boxes()
  {
    add_meta_box(
      'loan_application_details',
      'Детали заявки',
      'render_loan_application_meta_box',
      'loan_application',
      'normal',
      'high'
    );
  }

  public function save_loan_application($post_id, $post)
  {
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
      return;
    }

    if (isset($_POST['loan_status'])) {
      update_post_meta($post_id, '_status', sanitize_text_field($_POST['loan_status']));
    }
  }

  public function set_custom_columns($columns)
  {
    $new_columns = array();
    $new_columns['cb'] = $columns['cb'];
    $new_columns['title'] = $columns['title'];
    $new_columns['full_name'] = __('Full Name', 'loan-calculator');
    $new_columns['phone'] = __('Phone', 'loan-calculator');
    $new_columns['amount'] = __('Loan Amount', 'loan-calculator');
    $new_columns['term'] = __('Term', 'loan-calculator');
    $new_columns['monthly_payment'] = __('Monthly Payment', 'loan-calculator');
    $new_columns['status'] = __('Status', 'loan-calculator');
    $new_columns['date'] = $columns['date'];

    return $new_columns;
  }

  public function custom_column_content($column, $post_id)
  {
    $settings = get_option('loan_calculator_settings');
    $currency_symbol = esc_html($settings['currency_symbol'] ?? '₽');

    switch ($column) {
      case 'full_name':
        echo esc_html(get_post_meta($post_id, '_full_name', true));
        break;
      case 'phone':
        echo esc_html(get_post_meta($post_id, '_phone', true));
        break;
      case 'amount':
        $amount = get_post_meta($post_id, '_amount', true);
        echo number_format($amount, 0, ',', ' ') . ' ' . $currency_symbol;
        break;
      case 'term':
        $term = get_post_meta($post_id, '_term', true);
        echo esc_html($term) . ' лет';
        break;
      case 'monthly_payment':
        $monthly_payment = get_post_meta($post_id, '_monthly_payment', true);
        echo number_format($monthly_payment, 0, ',', ' ') . ' ' . $currency_symbol;
        break;
      case 'status':
        $status = get_post_meta($post_id, '_status', true);
        $statuses = [
          'new' => __('New', 'loan-calculator'),
          'processing' => __('Processing', 'loan-calculator'),
          'approved' => __('Approved', 'loan-calculator'),
          'rejected' => __('Rejected', 'loan-calculator')
        ];
        echo esc_html($statuses[$status] ?? $status);
        break;
    }
  }

  public function set_sortable_columns($columns)
  {
    $columns['amount'] = 'amount';
    $columns['term'] = 'term';
    $columns['status'] = 'status';
    return $columns;
  }

  public function add_settings_link($links)
  {
    $settings_link = sprintf(
      '<a href="%s">%s</a>',
      admin_url('options-general.php?page=loan-calculator'),
      __('Settings', 'loan-calculator')
    );
    array_unshift($links, $settings_link);
    return $links;
  }
}

new LoanCalculator();
